@@ -785,8 +785,8 @@ def parameters():
                 [1.1975e-02, 0.0],
             ],
             "tx_specs": {"type": "VMD", "a": 1.0, "I": 1.0},
-            "tx_offsets": [[-13.25, 0, 0]],
-            "bird_offset": [-26.5, 0, 0],
+            "tx_offsets": [[-13.25, 0, 2.0]],
+            "bird_offset": [-13.25, 0, 2.0],
             "normalization": [1e-12],
             "data_type": "dBzdt",
         },
@@ -964,8 +964,8 @@ def parameters():
                 [1.07e-02, 0.0e00],
             ],
             "tx_specs": {"type": "VMD", "a": 1.0, "I": 1.0},
-            "tx_offsets": [[-13.25, 0, 0]],
-            "bird_offset": [-26.5, 0, 0],
+            "tx_offsets": [[-13.25, 0, 2.0]],
+            "bird_offset": [-13.25, 0, 2.0],
             "normalization": [1e-12],
             "data_type": "dBzdt",
         },
@@ -974,86 +974,86 @@ def parameters():
             "flag": "HM",
             "channel_start_index": 20,
             "channels": {
-                "[1]": 7.115e-06,
-                "[2]": 8.615e-06,
-                "[3]": 1.0615e-05,
-                "[4]": 1.2615e-05,
-                "[5]": 1.4615e-05,
-                "[6]": 1.6615e-05,
-                "[7]": 1.8615e-05,
-                "[8]": 2.1115e-05,
-                "[9]": 2.4615e-05,
-                "[10]": 2.9115e-05,
-                "[11]": 3.4615e-05,
-                "[12]": 4.1615e-05,
-                "[13]": 5.0615e-05,
-                "[14]": 6.2115e-05,
-                "[15]": 7.6615e-05,
-                "[16]": 9.4615e-05,
-                "[17]": 11.7115e-05,
-                "[18]": 14.5115e-05,
-                "[19]": 18.0615e-05,
-                "[20]": 22.6114e-05,
-                "[21]": 28.3115e-05,
-                "[22]": 35.5115e-05,
-                "[23]": 44.6114e-05,
-                "[24]": 56.0115e-05,
-                "[25]": 70.4115e-05,
-                "[26]": 88.5615e-05,
-                "[27]": 110.8614e-5,
-                "[28]": 137.7614e-5,
-                "[29]": 169.9114e-5,
-                "[30]": 207.8615e-5,
-                "[31]": 252.2614e-5,
-                "[32]": 303.7114e-5,
-                "[33]": 362.6614e-5,
-                "[34]": 431.4114e-5,
-                "[35]": 513.2115e-5,
-                "[36]": 610.5614e-5,
-                "[37]": 726.4614e-5,
-                "[38]": 864.3614e-5,
-                "[39]": 1028.3615e-5,
+                "[1]": 7.15e-07,
+                "[2]": 2.215e-06,
+                "[3]": 4.215e-06,
+                "[4]": 6.215e-06,
+                "[5]": 8.215e-06,
+                "[6]": 1.0215e-05,
+                "[7]": 1.2215e-05,
+                "[8]": 1.4715e-05,
+                "[9]": 1.8215e-05,
+                "[10]": 2.2715e-05,
+                "[11]": 2.8215e-05,
+                "[12]": 3.5215e-05,
+                "[13]": 4.4215e-05,
+                "[14]": 5.5715e-05,
+                "[15]": 7.0215e-05,
+                "[16]": 8.8215e-05,
+                "[17]": 0.000110715,
+                "[18]": 0.000138715,
+                "[19]": 0.000174215,
+                "[20]": 0.000219715,
+                "[21]": 0.000276715,
+                "[22]": 0.000348715,
+                "[23]": 0.000439715,
+                "[24]": 0.000553715,
+                "[25]": 0.000697715,
+                "[26]": 0.000879215,
+                "[27]": 0.001102215,
+                "[28]": 0.001371215,
+                "[29]": 0.001692715,
+                "[30]": 0.002072215,
+                "[31]": 0.002516215,
+                "[32]": 0.003030715,
+                "[33]": 0.003620215,
+                "[34]": 0.004307715,
+                "[35]": 0.005125715,
+                "[36]": 0.006099215,
+                "[37]": 0.007258215,
+                "[38]": 0.008637215,
+                "[39]": 0.010277215,
             },
             "uncertainty": [
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
-                [0.05, 1e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
+                [0.05, 5e-2],
             ],
             "waveform": [
                 [-3.650e-03, 1e-8],
@@ -1158,8 +1158,8 @@ def parameters():
                 [1.751e-03, 0.000e00],
             ],
             "tx_specs": {"type": "VMD", "a": 1.0, "I": 1.0},
-            "tx_offsets": [[-16.1, 0, 0]],
-            "bird_offset": [-31.1, 0, 0],
+            "tx_offsets": [[-16.7, 0, 2.0]],
+            "bird_offset": [-16.7, 0, 2.0],
             "normalization": [1e-12],
             "data_type": "dBzdt",
         },
